@@ -2,22 +2,10 @@
 /////////////////////////////////////////////////
 // PukiWiki - Yet another WikiWikiWeb clone.
 //
-// $Id: source.inc.php,v 1.4.2.1 2003/03/13 06:03:15 panda Exp $
+// $Id: source.inc.php,v 1.11 2004/02/29 07:53:55 arino Exp $
 //
 // ڡɽ
 
-function plugin_source_init()
-{
-	$messages = array(
-		'_source_messages'=>array(
-			'msg_title' => '$1Υ',
-			'msg_notfound' => '$1Ĥޤ',
-			'err_notfound' => 'ڡΥɽǤޤ'
-		)
-	);
-	set_plugin_messages($messages);
-}
-
 function plugin_source_action()
 {
 	global $vars;
@@ -25,7 +13,7 @@ function plugin_source_action()
 	
 	$vars['refer'] = $vars['page'];
 	
-	if (!is_page($vars['page']))
+	if (!is_page($vars['page']) || !check_readable($vars['page'],false,false))
 	{
 		return array(
 			'msg'=>$_source_messages['msg_notfound'],
